@@ -60,12 +60,18 @@ workers <- function(cores) {
     cores
   } else {
     cores <- getOption('cores')
-    if (!is.null(cores))
+    if (!is.null(cores)) {
       # use the number specified via the 'cores' option
       cores
-    else
-      # use the number detected by multicore
-      multicore:::volatile$detectedCores
+    } else {
+    # use the number detected by parallel 
+      cores <- parallel::detectCores()
+      if (cores > 2) {
+        # try to use about half the cores
+          cores <- ceiling(cores/2)
+        }
+      cores
+    }
   }
 }
 
@@ -78,17 +84,14 @@ info <- function(data, item) {
          NULL)
 }
 
-comp <- if (getRversion() < "2.13.0") {
-  function(expr, ...) expr
-} else {
-  function(expr, ...) {
+comp <- function(expr, ...) {
     if (isTRUE(.options$nocompile))
       expr
     else
       compiler::compile(expr, ...)
-  }
 }
 
+
 doMC <- function(obj, expr, envir, data) {
   # set the default mclapply options
   preschedule <- TRUE
